@@ -4,7 +4,7 @@ from functools import reduce
 import collections
 import os
 import pathlib
-import threading
+from threading import Event, Thread
 import glob
 
 class Helpers:
@@ -38,13 +38,10 @@ class Helpers:
 
     #This functions executes the function function_handler periodically each number of seconds given by sec
     #imitates the functionallity of the nodejs funciton setInterval
-    def set_interval(self, function_handler, sec):
-        def func_wrapper():
-            self.set_interval(function_handler, sec)
-            function_handler()
-
-        self.thread_set_interval = threading.Timer(sec, func_wrapper)
-        self.thread_set_interval.start()
-
-    def stop_set_interval_thread(self):
-        self.thread_set_interval.cancel()
\ No newline at end of file
+    def set_interval(self, function_handler, sec, *args):
+        stopped = Event()
+        def loop():
+            while not stopped.wait(sec): # the first call is in `interval` secs
+                function_handler(*args)
+        Thread(target=loop).start()    
+        return stopped.set
